@@ -8,7 +8,7 @@ class VersionManager(object):
 
     # m_pkg_name = 'pandas-coder'
     m_pkg_name = 'pdcoder'
-    m_current_version = tuple('0.3.3'.split('.'))
+    m_current_version = tuple('0.3.4'.split('.'))
     m_version_re = re.compile(r'\((from versions: (.*?))\)')
 
     def has_updated(self) -> bool:
@@ -30,11 +30,7 @@ class VersionManager(object):
         import sys
         import os
         os.system(
-            'start pip install pdcoder -U  && python main.py && echo done;pause')
-        # subprocess.Popen(
-        #     'pip install pdcoder -U  && python main.py && echo done', shell=True)
-        sys.exit(0)
-        # self._use_pip(['install', self.m_pkg_name, '-U'])
+            'pip install pdcoder -U  && python main.py')
 
     def _use_pip(self, cmds: List[str]):
         # cmds = ['pip'] + cmds + ['-i', 'https://pypi.douban.com/simple/']
